@@ -3,7 +3,7 @@
 import django_tables2 as tables
 from django.utils.html import format_html
 from django.urls import reverse
-from schema.funcs import boolicon, colouricon
+from schema.funcs import boolicon, colouricon, locationicon
 
 # Import all models that need admin pages
 from schema.models import Accessory, Archive, Battery, BulkFilm, Camera, CameraModel, Developer, Enlarger, EnlargerModel, FilmStock, Filter
@@ -96,11 +96,13 @@ class BulkFilmTable(tables.Table):
         return format_html("{}m", value)
 
 class CameraTable(tables.Table):
+    cameramodel = tables.Column(verbose_name= 'Camera model')
+    cameramodel__lens_model_name = tables.Column(verbose_name= 'Lens model')
     class Meta:
         attrs = {"class": "table table-hover"}
         model = Camera
-        fields = ('id_owner', 'cameramodel', 'serial',
-                  'manufactured', 'cameramodel__lens_model_name', 'own')
+        fields = ('id_owner', 'cameramodel', 'serial', 'manufactured',
+                 'cameramodel__mount', 'cameramodel__lens_model_name', 'own')
 
     @classmethod
     def render_id_owner(cls, value):
@@ -197,6 +199,7 @@ class EnlargerModelTable(tables.Table):
 
 
 class EnlargerTable(tables.Table):
+    enlargermodel = tables.Column(verbose_name= 'Enlarger model')
     class Meta:
         attrs = {"class": "table table-hover"}
         model = Enlarger
@@ -257,6 +260,7 @@ class FlashModelTable(tables.Table):
 
 
 class FlashTable(tables.Table):
+    flashmodel = tables.Column(verbose_name= 'Flash model')
     class Meta:
         attrs = {"class": "table table-hover"}
         model = Flash
@@ -283,6 +287,7 @@ class FormatTable(tables.Table):
 
 
 class LensTable(tables.Table):
+    lensmodel = tables.Column(verbose_name= 'Lens model')
     class Meta:
         attrs = {"class": "table table-hover"}
         model = Lens
@@ -504,8 +509,8 @@ class PrintTable(tables.Table):
     class Meta:
         attrs = {"class": "table table-hover"}
         model = Print
-        fields = ('id_owner', 'negative', 'date', 'paper_stock',
-                  'width', 'height', 'location', 'archive')
+        fields = ('id_owner', 'negative', 'date',
+                  'width', 'height', 'own', 'archive')
 
     @classmethod
     def render_id_owner(cls, value):
@@ -515,6 +520,22 @@ class PrintTable(tables.Table):
     def render_negative(cls, value):
         return format_html("<a href=\"{}\">{}</a>", reverse('schema:negative-detail', args=[value.slug]), value)
 
+    @classmethod
+    def render_width(cls, value):
+        return format_html("{}\"", value)
+
+    @classmethod
+    def render_height(cls, value):
+        return format_html("{}\"", value)
+
+    @classmethod
+    def render_own(cls, value):
+        return format_html(boolicon(value))
+
+    @classmethod
+    def render_archive(cls, value):
+        return format_html("<a href=\"{}\">{}</a>", reverse('schema:archive-detail', args=[value.id_owner]), value)
+
 
 class ProcessTable(tables.Table):
     class Meta:
@@ -536,6 +557,7 @@ class ProcessTable(tables.Table):
 
 
 class ScanTable(tables.Table):
+    uuid = tables.Column(verbose_name= 'UUID')
     class Meta:
         attrs = {"class": "table table-hover"}
         model = Scan
@@ -562,7 +584,7 @@ class NegativeTable(tables.Table):
     class Meta:
         attrs = {"class": "table table-hover"}
         model = Negative
-        fields = ('slug', 'film', 'date', 'lens', 'shutter_speed', 'aperture')
+        fields = ('slug', 'film', 'date', 'location', 'film__camera', 'lens', 'shutter_speed', 'aperture')
 
     @classmethod
     def render_slug(cls, value, record):
@@ -576,16 +598,25 @@ class NegativeTable(tables.Table):
     def render_film(cls, value):
         return format_html("<a href=\"{}\">{}</a>", reverse('schema:film-detail', args=[value.id_owner]), value)
 
+    @classmethod
+    def render_location(cls, value):
+        return format_html(locationicon(value))
+
+    @classmethod
+    def render_film__camera(cls, value):
+        return format_html("<a href=\"{}\">{}</a>", reverse('schema:camera-detail', args=[value.id_owner]), value)
+
     @classmethod
     def render_lens(cls, value):
         return format_html("<a href=\"{}\">{}</a>", reverse('schema:lens-detail', args=[value.id_owner]), value)
 
 class FilmTable(tables.Table):
+    negative_set__count = tables.Column(verbose_name= 'Frames')
     class Meta:
         attrs = {"class": "table table-hover"}
         model = Film
         fields = ('id_owner', 'filmstock', 'format',
-                  'status', 'date_processed', 'camera')
+                  'status', 'negative_set__count', 'date_processed', 'camera')
 
     @classmethod
     def render_id_owner(cls, value, record):
@@ -605,6 +636,7 @@ class FilmTable(tables.Table):
 
 
 class TeleconverterTable(tables.Table):
+    teleconvertermodel = tables.Column(verbose_name= 'Teleconverter model')
     class Meta:
         attrs = {"class": "table table-hover"}
         model = Teleconverter
